Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(627)

Unified Diff: chrome/common/extensions/extension_action.cc

Issue 11043004: Merge 157903 - Turn off animations for page actions and browser actions. (Closed) Base URL: svn://svn.chromium.org/chrome/branches/1271/src/
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/common/extensions/extension_action_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/extensions/extension_action.cc
===================================================================
--- chrome/common/extensions/extension_action.cc (revision 159746)
+++ chrome/common/extensions/extension_action.cc (working copy)
@@ -319,9 +319,10 @@
SetValue(&appearance_, tab_id, new_appearance);
- // When showing a badge for the first time on a web page, fade it
- // in. Other transitions happen instantly.
- if (old_appearance == INVISIBLE && tab_id != kDefaultTabId) {
+ // When showing a script badge for the first time on a web page, fade it in.
+ // Other transitions happen instantly.
+ if (old_appearance == INVISIBLE && tab_id != kDefaultTabId &&
+ action_type_ == TYPE_SCRIPT_BADGE) {
RunIconAnimation(tab_id);
}
« no previous file with comments | « no previous file | chrome/common/extensions/extension_action_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698